@@ -18,7 +18,7 @@ available_studies <- function(base_url =  NULL) {
   url_path <- paste0("studies/")
   res <- cbp_api(url_path, base_url = base_url)$content %>%
     dplyr::bind_rows(.) %>%
-    select(.data$studyId, everything())
+    select("studyId", everything())
 
   return(res)
 }
