@@ -18,6 +18,7 @@ test_that("With study_id-  works fine", {
                      get_study_info = get_study_info,
                      available_samples = available_samples,
                      available_patients = available_patients,
+                     available_sample_lists = available_sample_lists,
 
                      get_mutations_by_study = get_mutations_by_study,
                      get_cna_by_study = get_cna_by_study,
@@ -47,6 +48,7 @@ test_that("Missing study_id - arg throws an error", {
                      get_study_info = get_study_info,
                      available_samples = available_samples,
                      available_patients = available_patients,
+                     available_sample_lists = available_sample_lists,
 
                      get_mutations_by_study = get_mutations_by_study,
                      get_cna_by_study = get_cna_by_study,
@@ -79,6 +81,7 @@ test_that("Incorrect study_id - API error", {
                      get_study_info = get_study_info,
                      available_samples = available_samples,
                      available_patients = available_patients,
+                     available_sample_lists = available_sample_lists,
 
                      get_mutations_by_study = get_mutations_by_study,
                      get_cna_by_study = get_cna_by_study,
@@ -130,6 +133,7 @@ test_that("More than 1 study_id - throws an error", {
                      get_study_info = get_study_info,
                      available_samples = available_samples,
                      available_patients = available_patients,
+                     available_sample_lists = available_sample_lists,
 
                      get_mutations_by_study = get_mutations_by_study,
                      get_cna_by_study = get_cna_by_study,
@@ -144,6 +148,22 @@ test_that("More than 1 study_id - throws an error", {
 
 })
 
+test_that("available_samples() works with sample_list_id", {
+
+  skip_on_cran()
+  skip_if(httr::http_error("www.cbioportal.org/api"))
+
+  db_test <- "public"
+  set_cbioportal_db(db = db_test)
+
+  expect_error(x <- available_samples(sample_list_id = "prad_msk_2019_cna"), NA)
+  expect_error(y <- available_samples(sample_list_id = "prad_msk_2019_cna",
+                                 study_id = "something_ignored"), NA)
+
+  expect_equal(x, y)
+
+  })
+
 
 # * Clinical Data  -----------------
 
@@ -200,3 +220,23 @@ test_that("Clinical data by study- 2 attributes ", {
   expect_equal(sort(unique(res$clinicalAttributeId)), sort(clinical_attribute))
 })
 
+test_that("Clinical data by study- returns patient and sample level ", {
+
+  skip_on_cran()
+  skip_if(httr::http_error("www.cbioportal.org/api"))
+
+  db_test <- "public"
+  set_cbioportal_db(db = db_test)
+  study_id = "acc_tcga"
+  clinical_attribute = c("CANCER_TYPE", "SAMPLE_TYPE", "AGE")
+
+  expect_no_error(
+    res <- get_clinical_by_study(study_id = study_id,
+                          clinical_attribute))
+
+
+  expect_equal(sort(unique(res$clinicalAttributeId)), sort(clinical_attribute))
+  expect_equal(sum(is.na(res$sampleId)), sum(res$dataLevel == "PATIENT"))
+
+})
+
